@@ -22,7 +22,7 @@
  * 
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  * 
- * $Id: pfsinimgmagick.cpp,v 1.5 2008/10/03 19:07:34 rafm Exp $
+ * $Id: pfsinimgmagick.cpp,v 1.6 2014/09/03 08:57:48 rafm Exp $
  */
 
 #include <config.h>
@@ -172,7 +172,7 @@ void readFrames( int argc, char* argv[] )
     frame->getTags()->setString( "FILE_NAME", fileNameTag );
  
     char strbuf[3];
-    snprintf( strbuf, 3, "%d", imImage.depth() );
+    snprintf( strbuf, 3, "%d", (int)imImage.depth() );
     frame->getTags()->setString("BITDEPTH", strbuf );    
    
     pfsio.writeFrame( frame, stdout );
