@@ -37,6 +37,10 @@ else
         % of the standard libraries 
         set_ld_path='export LD_LIBRARY_PATH=`echo $LD_LIBRARY_PATH | sed "y/:/\n/" | grep -v "matlab" | sed ":beg;N;s/\n/:/;t beg;"`';
         
+        if( strcmp( computer, 'MACI64' ) || strcmp( computer, 'MACI32' ) )
+            set_ld_path=cat( 2, set_ld_path, '; export DYLD_FRAMEWORK_PATH=`echo $DYLD_FRAMEWORK_PATH | sed "y/:/\n/" | grep -v "matlab" | sed ":beg;N;s/\n/:/;t beg;"`' );
+        end
+        
         % Start shell, cd to the working directory and remove matlab
         % libraries
         cmd = sprintf('/bin/bash -l -c ''cd "%s"; %s;', work_dir, set_ld_path );
