@@ -3,11 +3,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef __linux__
-#include <unistd.h>
-#else
+#if defined( __win32__ )
 #include <io.h>
 #include <process.h>
+#else
+#include <unistd.h>
 #endif
 
 #include "mex.h"
