@@ -24,14 +24,17 @@
  * 
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: pfs.cpp,v 1.12 2010/07/04 10:12:55 rafm Exp $
+ * $Id: pfs.cpp,v 1.13 2014/09/17 15:07:18 rafm Exp $
  */
 
 #if !defined(_MSC_VER) && !defined(_MATLAB_VER)
 #include <config.h>
 #endif
 
-#if defined(_MSC_VER) || defined(__CYGWIN__)
+// This does not seem to be needed under Cygwin
+//#if defined(_MSC_VER) || defined(__CYGWIN__)
+
+#if defined(_MSC_VER)
 #include <io.h>
 #define HAVE_SETMODE
 #endif
@@ -525,7 +528,7 @@ static void writeTags( const TagContainerImpl *tags, FILE *out )
   TagList::const_iterator it;
   fprintf( out, "%d" PFSEOL, tags->getSize() );
   for( it = tags->tagsBegin(); it != tags->tagsEnd(); it++ ) {
-    fprintf( out, (const char*)(it->c_str()) );
+    fputs( (const char*)(it->c_str()), out );
     fprintf( out, PFSEOL );
   }
 }
