@@ -34,7 +34,7 @@
  * 
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: pfs.h,v 1.2 2006/03/01 17:21:16 rafm Exp $
+ * $Id: pfs.h,v 1.5 2014/04/05 22:04:13 rafm Exp $
  */
 
 #ifndef PFS_H
@@ -42,9 +42,10 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <getopt.h>
 #include "array2d.h"
 
-struct option;
+//struct option;
 
 /**
  * All classes and function from PFS library reside in pfs namespace. 
@@ -125,6 +126,10 @@ namespace pfs
        * Returns true if there is still an item left on the list.
        */
       virtual bool hasNext() const = 0;
+
+      virtual ~TagIterator()
+	{
+	}
     };
 
   typedef SelfDestructPtr<TagIterator> TagIteratorPtr;
@@ -234,6 +239,10 @@ namespace pfs
        * Returns true if there is still an item left on the list.
        */
       virtual bool hasNext() const = 0;
+
+      virtual ~ChannelIterator()
+	{
+	}
     };
   
   typedef SelfDestructPtr<ChannelIterator> ChannelIteratorPtr;
@@ -305,8 +314,8 @@ namespace pfs
 
 
     /**
-     * Removes a channel. It is safe to remove the channel pointed by
-     * the ChannelIterator.
+     * Removes a channel and frees the memory allocated for it. It is
+     * safe to remove the channel pointed by the ChannelIterator.
      *
      * @param channel [in] channel that should be removed.
      */        
@@ -499,6 +508,7 @@ namespace pfs
       FrameFileIterator( int &argc, char* argv[], const char *fopenMode,
         const char *fileNamePrefix = NULL, FILE *stdinout = NULL,
         const char *optstring = NULL, const struct option *getopt_long = NULL );
+
       ~FrameFileIterator();
 
       /**
