@@ -22,7 +22,7 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: luminancerange_widget.cpp,v 1.5 2011/03/22 21:57:01 rafm Exp $
+ * $Id: luminancerange_widget.cpp,v 1.6 2013/12/21 19:42:28 rafm Exp $
  */
 
 #include <config.h>
@@ -190,7 +190,7 @@ void LuminanceRangeWidget::mousePressEvent ( QMouseEvent * me )
   update();
 }
 
-void LuminanceRangeWidget::mouseReleaseEvent ( QMouseEvent * me )
+void LuminanceRangeWidget::mouseReleaseEvent ( QMouseEvent * )
 {
 
   float newWindowMin = draggedMin();
