@@ -22,7 +22,7 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: main.cpp,v 1.18 2011/04/30 14:01:17 rafm Exp $
+ * $Id: main.cpp,v 1.19 2014/10/13 09:27:38 rafm Exp $
  */
 
 #include <config.h>
@@ -445,6 +445,9 @@ void PFSViewMainWin::updatePointerValue()
         pfs::transformColorSpace( pfs::CS_XYZ, &X, &Y, &Z, pfs::CS_Yxy, &X, &Y, &Z );
         l1 = "Y"; l2 = "x"; l3 = "y";
         break;
+      case CC_COUNT:
+	assert( 0 );
+	break;
       };
       
       sprintf( pointerValueStr, "%s=%07.4g %s=%07.4g %s=%07.4g",
