@@ -22,7 +22,7 @@
  *
  * @author Rafal Mantiuk, <mantiuk@mpi-sb.mpg.de>
  *
- * $Id: pfsview_widget.cpp,v 1.21 2011/04/30 14:01:17 rafm Exp $
+ * $Id: pfsview_widget.cpp,v 1.26 2014/10/13 09:27:38 rafm Exp $
  */
 
 #include <config.h>
@@ -45,6 +45,9 @@
 
 #include "pfsview_widget.h"
 
+//#include "pfsglviewwidget.h"
+
+
 #include <assert.h>
 
 #define min(x,y) ( (x)<(y) ? (x) : (y) )
@@ -319,10 +322,8 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
   assert( img != NULL );
   int rows = R->getRows();
   int cols = R->getCols();
-  int index = 0;
   bool expand = cols != img->width() || rows != img->height(); // Zoom in
 
-  float imgRow = 0, imgCol;
   float imgDeltaRow, imgDeltaCol;
   if( expand ) {
     imgDeltaRow = (float)(img->height()) / (float)rows;
@@ -357,11 +358,11 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
       lutPixel[0] = negativeTreatment == NEGATIVE_GREEN_SCALE ?
         QColor( 0, 255, 255 ).rgb() : QColor( 255, 255, 0 ).rgb();
       lutPixel[257] = QColor( 0, 0, 255 ).rgb();
-      lutPixel[257*2] = QColor( 255, 255, 0 ).rgb();
+      lutPixel[257*2-1] = QColor( 255, 255, 0 ).rgb();
     } else {
       lutPixel[0] = lutPixel[1];
       lutPixel[257] = QColor( 0, 0, 0 ).rgb();
-      lutPixel[257*2] = QColor( 255, 255, 255 ).rgb();
+      lutPixel[257*2-1] = QColor( 255, 255, 255 ).rgb();
     }  
     
   } else {                      // clip negative numbers
@@ -388,7 +389,12 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
 
 //  bool once = true;
   
-  for( int r = 0; r < rows; r++, imgRow += imgDeltaRow ) {
+ // #pragma omp parallel for private (index)
+  #pragma omp parallel for
+  for( int r = 0; r < rows; r++ ) {
+	float imgRow, imgCol;
+	int index = r*cols;
+	imgRow = (float)r * imgDeltaRow;
     QRgb* line = (QRgb*)img->scanLine( (int)imgRow );
     imgCol = 0;
     for( int c = 0; c < cols; c++, index++, imgCol += imgDeltaCol ) {
@@ -465,7 +471,7 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
             clamp( pb-1, 0, 255 ) ).rgb();
         }
         if( infNaNTreatment == INFNAN_MARK_AS_RED ) {
-          if( !finite( (*R)(index) ) || !finite( (*G)(index) ) || !finite( (*B)(index) ) )
+          if( !isfinite( (*R)(index) ) || !isfinite( (*G)(index) ) || !isfinite( (*B)(index) ) )
           {   // x is NaN or Inf 
             pixel = QColor( 255, 0, 0 ).rgb();
           }
@@ -482,7 +488,7 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
         int p = binarySearchPixels( (*R)(index), lutPixFloor, lutSize );        
         pixel = lutPixel[p];
         if( infNaNTreatment == INFNAN_MARK_AS_RED && (p == 0 || p == LUTSIZE+1)) 
-          if( !finite( (*R)(index) ) ) {   // x is NaN or Inf 
+          if( !isfinite( (*R)(index) ) ) {   // x is NaN or Inf 
             pixel = QColor( 255, 0, 0 ).rgb();
           }
         
@@ -495,15 +501,17 @@ static void mapFrameToImage( pfs::Array2D *R, pfs::Array2D *G, pfs::Array2D *B,
           line[ec] = pixel;
         }
       }
+	  	  
     }
 
     if( expand ) {
-      for( int er = (int)imgRow + 1; er < (int)(imgRow + imgDeltaRow); er++ ) {
+      for( int er = (int)(imgRow + 1); er < (int)(imgRow + imgDeltaRow); er++ ) {
         QRgb* eLine = (QRgb*)img->scanLine( er );
         memcpy( eLine, line, sizeof( QRgb )*img->width() );
       }
       
     }
+
   }
   
 }
